==> haskell-clock-0.7.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-clock.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clock
version: 0.7.2
id: clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs
key: clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs
license: BSD-3-Clause
copyright: Copyright © Cetin Sert 2009-2016, Eugene Kirpichov 2010, Finn Espen Gundersen 2013, Gerolf Seitz 2013, Mathieu Boespflug 2014 2015, Chris Done 2015, Dimitri Sabadie 2015, Christian Burger 2015, Mario Longobardi 2016
maintainer: Cetin Sert <cetin@corsis.eu>, Corsis Research
author: Cetin Sert <cetin@corsis.eu>, Corsis Research
stability: stable
homepage: https://github.com/corsis/clock
synopsis: High-resolution clock functions: monotonic, realtime, cputime.
description:
    A package for convenient access to high-resolution clock and
    timer functions of different operating systems via a unified API.
    .
    POSIX code and surface API was developed by Cetin Sert in 2009.
    .
    Windows code was contributed by Eugene Kirpichov in 2010.
    .
    FreeBSD code was contributed by Finn Espen Gundersen on 2013-10-14.
    .
    OS X code was contributed by Gerolf Seitz on 2013-10-15.
    .
    Derived @Generic@, @Typeable@ and other instances for @Clock@ and @TimeSpec@ was contributed by Mathieu Boespflug on 2014-09-17.
    .
    Corrected dependency listing for @GHC < 7.6@ was contributed by Brian McKenna on 2014-09-30.
    .
    Windows code corrected by Dimitri Sabadie on 2015-02-09.
    .
    Added @timeSpecAsNanoSecs@ as observed widely-used by Chris Done on 2015-01-06, exported correctly on 2015-04-20.
    .
    Imported Control.Applicative operators correctly for Haskell Platform on Windows on 2015-04-21.
    .
    Unit tests and instance fixes by Christian Burger on 2015-06-25.
    .
    Removal of fromInteger : Integer -> TimeSpec by Cetin Sert on 2015-12-15.
    .
    New Linux-specific Clocks: MonotonicRaw, Boottime, MonotonicCoarse, RealtimeCoarse by Cetin Sert on 2015-12-15.
    .
    Reintroduction fromInteger : Integer -> TimeSpec by Cetin Sert on 2016-04-05.
    .
    Fixes for older Linux build failures introduced by new Linux-specific clocks by Mario Longobardi on 2016-04-18.
    .
    [Version Scheme]
    Major-@/R/@-ewrite . New-@/F/@-unctionality . @/I/@-mprovementAndBugFixes . @/P/@-ackagingOnly
    .
    * @PackagingOnly@ changes are made for quality assurance reasons.
category: System
abi: aea2e14c40bb78b61c7d4fb8ecb421a3
exposed: True
exposed-modules:
    System.Clock
import-dirs: /usr/lib/ghc-8.4.3/site-local/clock-0.7.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/clock-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/clock-0.7.2
hs-libraries: HSclock-0.7.2-ErKmPTjVISxJnEb9XKUAOs
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-clock/html/clock.haddock
haddock-html: /usr/share/doc/haskell-clock/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clock-0.7.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-clock.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clock
version: 0.7.2
id: clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
key: clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
license: BSD-3-Clause
copyright: Copyright © Cetin Sert 2009-2016, Eugene Kirpichov 2010, Finn Espen Gundersen 2013, Gerolf Seitz 2013, Mathieu Boespflug 2014 2015, Chris Done 2015, Dimitri Sabadie 2015, Christian Burger 2015, Mario Longobardi 2016
maintainer: Cetin Sert <cetin@corsis.eu>, Corsis Research
author: Cetin Sert <cetin@corsis.eu>, Corsis Research
stability: stable
homepage: https://github.com/corsis/clock
synopsis: High-resolution clock functions: monotonic, realtime, cputime.
description:
    A package for convenient access to high-resolution clock and
    timer functions of different operating systems via a unified API.
    .
    POSIX code and surface API was developed by Cetin Sert in 2009.
    .
    Windows code was contributed by Eugene Kirpichov in 2010.
    .
    FreeBSD code was contributed by Finn Espen Gundersen on 2013-10-14.
    .
    OS X code was contributed by Gerolf Seitz on 2013-10-15.
    .
    Derived @Generic@, @Typeable@ and other instances for @Clock@ and @TimeSpec@ was contributed by Mathieu Boespflug on 2014-09-17.
    .
    Corrected dependency listing for @GHC < 7.6@ was contributed by Brian McKenna on 2014-09-30.
    .
    Windows code corrected by Dimitri Sabadie on 2015-02-09.
    .
    Added @timeSpecAsNanoSecs@ as observed widely-used by Chris Done on 2015-01-06, exported correctly on 2015-04-20.
    .
    Imported Control.Applicative operators correctly for Haskell Platform on Windows on 2015-04-21.
    .
    Unit tests and instance fixes by Christian Burger on 2015-06-25.
    .
    Removal of fromInteger : Integer -> TimeSpec by Cetin Sert on 2015-12-15.
    .
    New Linux-specific Clocks: MonotonicRaw, Boottime, MonotonicCoarse, RealtimeCoarse by Cetin Sert on 2015-12-15.
    .
    Reintroduction fromInteger : Integer -> TimeSpec by Cetin Sert on 2016-04-05.
    .
    Fixes for older Linux build failures introduced by new Linux-specific clocks by Mario Longobardi on 2016-04-18.
    .
    [Version Scheme]
    Major-@/R/@-ewrite . New-@/F/@-unctionality . @/I/@-mprovementAndBugFixes . @/P/@-ackagingOnly
    .
    * @PackagingOnly@ changes are made for quality assurance reasons.
category: System
abi: ec7667e6817f0708c3671c5e597181e9
exposed: True
exposed-modules:
    System.Clock
import-dirs: /usr/lib/ghc-8.6.1/site-local/clock-0.7.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/clock-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/clock-0.7.2
hs-libraries: HSclock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-clock/html/clock.haddock
haddock-html: /usr/share/doc/haskell-clock/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
